@@ -13,13 +13,13 @@ have_tracker_miner_fs="$4"
 have_tracker_miner_rss="$5"
 
 mkdir -p ${DESTDIR}/${tracker_miner_services_dir}
-if [[ "$have_tracker_miner_apps" -eq "true" ]]; then
+if ([ "$have_tracker_miner_apps" = "true" ]); then
   ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.Applications.service" "${DESTDIR}/${tracker_miner_services_dir}/"
 fi
 ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.Extract.service" "${DESTDIR}/${tracker_miner_services_dir}/"
-if [[ "$have_tracker_miner_fs" -eq "true" ]]; then
+if ([ "$have_tracker_miner_fs" = "true" ]); then
   ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.Files.service" "${DESTDIR}/${tracker_miner_services_dir}/"
 fi
-if [[ "$have_tracker_miner_rss" -eq "true" ]]; then
+if ([ "$have_tracker_miner_rss" = "true" ]); then
   ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.RSS.service" "${DESTDIR}/${tracker_miner_services_dir}/"
 fi
